@@ -232,9 +232,9 @@ class MyWhatify:
             pipeline = cls.get_pipeline_estimators_list(dataset_id, True, interpt_level)
             estimators = cls.get_pipeline_estimators_list(dataset_id, False, interpt_level)
             if interpt_level == Interpt.EXPLAINABLE:
-                interpretability_level = my_toolkit.enums.InterpretabilityLevel.EXPLAINABLE
+                interpretability_level = my_toolkit.vars_global.InterpretabilityLevel.EXPLAINABLE
             else:
-                interpretability_level = my_toolkit.enums.InterpretabilityLevel.PRECISE
+                interpretability_level = my_toolkit.vars_global.InterpretabilityLevel.PRECISE
 
             # print('The training time is:', Training_time_in_minutes)
             # print ('The selected Target Metric is:', Target_metric.value)
@@ -555,7 +555,7 @@ class MyWhatify:
     def get_data_file(cls, data_name='car_sdk_demo.csv'):
         with allure.step('getting csv from data file for data_name: ' + str(data_name)):
             script_dir = os.path.dirname(__file__)
-            path = os.path.join(script_dir, '../data_source/')
+            path = os.path.join(script_dir, 'data_source/')
             # path = "https://raw.githubusercontent.com/NeuralAlgorithms/firefly-python-sdk/master/examples/"
         return pd.read_csv(path + data_name)
 
